NWindow class

Constructors

NWindow()
factory

Properties

adsLoaded int
final
hashCode int
The hash code for this object.
no setterinherited
openController String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoDictionary HttpServer?
getter/setter pair

Methods

deleteCachedVideos({List<String>? videoNames, required bool mode, required List<String> identifiers}) Future<List<Map<String, dynamic>>>
downloadVideos(List<String> urls, {List? identifiers, bool waitAll = true}) Future<List<Map<String, dynamic>>>
downloadVideosSequential(List<String> urls, {List? identifiers, bool waitAll = true}) Future<List<Map<String, dynamic>>>
getRandomString({int minLength = 3, int maxLength = 5}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startWebServerIfNeeded() Future<void>
stopWebServer() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

debugRegister_87 NWindow
final