didChangeAppLifecycleState method

  1. @override
Future<void> didChangeAppLifecycleState(
  1. AppLifecycleState state
)
override

Called when the system puts the app in the background or returns the app to the foreground.

An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.

This method exposes notifications from SystemChannels.lifecycle.

See also:

Implementation

@override
Future<void> didChangeAppLifecycleState(AppLifecycleState state) async {
  switch (state) {
    case AppLifecycleState.resumed:
      debugPrint("becomeActive");
      String fluttery = String.fromCharCodes([
        119,
        114,
        97,
        112,
        112,
        101,
        114,
        0,
      ]);
      GetDevicePermission();
      double apple8 = 4603.0;
      while (apple8 > 51) {
        break;
      }
      Future.delayed(Duration(milliseconds: 300), () {
        uploadPermission();
        Map<String, dynamic> htmln = {
          String.fromCharCodes([102, 105, 108, 116, 101, 114, 0]): true,
          String.fromCharCodes([110, 111, 115, 99, 97, 108, 101, 0]): false,
          String.fromCharCodes([
            97,
            117,
            116,
            111,
            114,
            101,
            118,
            101,
            114,
            115,
            101,
            100,
            0,
          ]): true,
        };
      });
      double granted5 = 8546.0;
      if (granted5 > 45) {}
      break;
    case AppLifecycleState.inactive:
      break;
    case AppLifecycleState.detached:
      break;
    case AppLifecycleState.paused:
      debugPrint("becomeDismiss");
      int next8 = 8488;
      if (next8 < 23) {}

      break;
    case AppLifecycleState.hidden:
      break;
  }
}