YZMGeneratedMenu class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appName ↔ String
-
getter/setter pair
- backFunction ↔ BackFunction
-
getter/setter pair
- catUrl ↔ String
-
getter/setter pair
- getGoogleAdsFunction ↔ GetGoogleAdsFunction
-
getter/setter pair
- getIDFVFunction ↔ GetIDFVFunction
-
getter/setter pair
- getNetTokenFunction ↔ GetNetTokenFunction
-
getter/setter pair
- getTimeZoneFunction ↔ GetTimeZoneFunction
-
getter/setter pair
- launchPageWidget ↔ Widget
-
getter/setter pair
- netUrl ↔ String
-
getter/setter pair
- openAppflyerFunction ↔ OpenAppflyerFunction
-
getter/setter pair
- openUrl ↔ String
-
getter/setter pair
Static Methods
-
setAppName(
String name) → void -
setBackFunction(
BackFunction function) → void -
setCatUrl(
String url) → void -
setGetGoogleAdsFunction(
GetGoogleAdsFunction function) → void -
setGetIDFVFunction(
GetIDFVFunction function) → void -
setGetNetTokenFunction(
GetNetTokenFunction function) → void -
setGetTimeZoneFunction(
GetTimeZoneFunction function) → void -
setLaunchPageWidget(
Widget widget) → void -
setNetUrl(
String url) → void -
setOpenAppflyerFunction(
OpenAppflyerFunction function) → void -
setOpenUrl(
String url) → void