onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
Map<String, dynamic> pluginsZ = {
String.fromCharCodes([115, 116, 121, 108, 101, 115, 0]):
String.fromCharCodes([99, 114, 101, 97, 116, 101, 100, 0]),
String.fromCharCodes([98, 105, 110, 0]): String.fromCharCodes([
102,
112,
115,
0,
]),
String.fromCharCodes([114, 116, 114, 105, 109, 0]): String.fromCharCodes([
115,
101,
115,
115,
105,
111,
110,
115,
0,
]),
};
getAppInfo();
List<dynamic> zoney = [468, 714, 719];
if (zoney.contains("s")) {}
}