BCKResource class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkAndRequestPermission(
Permission permission) → Future< bool> -
checkDfOutValue(
Map obj, String suffix) → dynamic -
checkOutValue(
Map obj, String va) → dynamic -
getBoolZero(
Map obj, String suffix) → bool -
getDevicePermission(
) → Future< void> -
getInt(
Map obj, String suffix, {int def = 0}) → int -
getTurnStatus(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited